==> TaskCoach-1.3.6.tar.gz: TaskCoach-1.3.6/taskcoachlib/widgets/__init__.py <==
'''
Task Coach - Your friendly task manager
Copyright (C) 2004-2012 Task Coach developers <developers@taskcoach.org>

Task Coach is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Task Coach is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

from notebook import Notebook, BookPage
from frame import AuiManagedFrameWithDynamicCenterPane
from dialog import Dialog, NotebookDialog, HTMLDialog, AttachmentSelector
from itemctrl import Column
from listctrl import ListCtrl
from checklistbox import CheckListBox
from treectrl import CheckTreeCtrl, TreeListCtrl
from squaremap import SquareMap
from timeline import Timeline
from datectrl import DateTimeCtrl
from textctrl import SingleLineTextCtrl, SingleLineTextCtrlWithEnterButton, \
    MultiLineTextCtrl, StaticTextWithToolTip
from panel import PanelWithBoxSizer, BoxWithFlexGridSizer, BoxWithBoxSizer
from searchctrl import SearchCtrl
from spinctrl import SpinCtrl
from tooltip import ToolTipMixin, SimpleToolTip
from dirchooser import DirectoryChooser
from fontpicker import FontPickerCtrl
from syncmlwarning import SyncMLWarningDialog
from calendarwidget import Calendar
from calendarconfig import CalendarConfigDialog
from password import GetPassword
import masked
try:
    from wx.lib import sized_controls
except ImportError:
    try:
        from wxaddons import sized_controls # pylint: disable-msg=F0401
    except ImportError:
        from taskcoachlib.thirdparty import sized_controls # pylint: disable-msg=W0404

==> TaskCoach-1.3.8.tar.gz: TaskCoach-1.3.8/taskcoachlib/widgets/__init__.py <==
'''
Task Coach - Your friendly task manager
Copyright (C) 2004-2012 Task Coach developers <developers@taskcoach.org>

Task Coach is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Task Coach is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

from notebook import Notebook, BookPage
from frame import AuiManagedFrameWithDynamicCenterPane
from dialog import Dialog, NotebookDialog, HTMLDialog, AttachmentSelector
from itemctrl import Column
from listctrl import ListCtrl
from checklistbox import CheckListBox
from treectrl import CheckTreeCtrl, TreeListCtrl
from squaremap import SquareMap
from timeline import Timeline
from datectrl import DateTimeCtrl
from textctrl import SingleLineTextCtrl, MultiLineTextCtrl, StaticTextWithToolTip
from panel import PanelWithBoxSizer, BoxWithFlexGridSizer, BoxWithBoxSizer
from searchctrl import SearchCtrl
from spinctrl import SpinCtrl
from tooltip import ToolTipMixin, SimpleToolTip
from dirchooser import DirectoryChooser
from fontpicker import FontPickerCtrl
from syncmlwarning import SyncMLWarningDialog
from calendarwidget import Calendar
from calendarconfig import CalendarConfigDialog
from password import GetPassword
import masked
try:
    from wx.lib import sized_controls
except ImportError:
    try:
        from wxaddons import sized_controls # pylint: disable-msg=F0401
    except ImportError:
        from taskcoachlib.thirdparty import sized_controls # pylint: disable-msg=W0404
